diff --git a/src/backend/executor/execProcnode.c b/src/backend/executor/execProcnode.c
index 47381cff4691c56bbd9961938c5ac8691c88c0c8..c89c7ffd899853b6163e9d7f7dc11a80a557260b 100644
--- a/src/backend/executor/execProcnode.c
+++ b/src/backend/executor/execProcnode.c
@@ -12,7 +12,7 @@
  *
  *
  * IDENTIFICATION
- *	  $PostgreSQL: pgsql/src/backend/executor/execProcnode.c,v 1.44 2004/08/29 04:12:31 momjian Exp $
+ *	  $PostgreSQL: pgsql/src/backend/executor/execProcnode.c,v 1.45 2004/09/24 01:36:30 neilc Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -293,7 +293,7 @@ ExecProcNode(PlanState *node)
 			break;
 
 		case T_AppendState:
-			result = ExecProcAppend((AppendState *) node);
+			result = ExecAppend((AppendState *) node);
 			break;
 
 			/*
diff --git a/src/backend/po/cs.po b/src/backend/po/cs.po
index ed79416b37a19f09dd8a809ca8c7b595ce4de1e3..d460251ab729c1df3b78e4c2d95dc19557dcf101 100644
--- a/src/backend/po/cs.po
+++ b/src/backend/po/cs.po
@@ -4961,7 +4961,7 @@ msgid "Unable to identify an equality operator for type '%s'"
 msgstr ""
 
 #: ../executor/nodeAppend.c:293
-msgid "ExecProcAppend: subnode is NULL"
+msgid "ExecAppend: subnode is NULL"
 msgstr ""
 
 #: ../executor/nodeHash.c:66
diff --git a/src/backend/po/hu.po b/src/backend/po/hu.po
index 40ca9186482a6b8e97c2e77ee69182a1213309f5..04848c9d211bf697fb8d235463e12fe4625a38bf 100644
--- a/src/backend/po/hu.po
+++ b/src/backend/po/hu.po
@@ -2,7 +2,7 @@
 # Zoltan Kovacs <kovzol@math.u-szeged.hu>, 2001.
 # Robert Zana <zerobert@freemail.hu>, 2001.
 #
-# $PostgreSQL: pgsql/src/backend/po/hu.po,v 1.6 2003/11/29 19:51:53 pgsql Exp $
+# $PostgreSQL: pgsql/src/backend/po/hu.po,v 1.7 2004/09/24 01:36:34 neilc Exp $
 #
 msgid ""
 msgstr ""
@@ -4925,7 +4925,7 @@ msgid "Unable to identify an equality operator for type '%s'"
 msgstr ""
 
 #: ../executor/nodeAppend.c:293
-msgid "ExecProcAppend: subnode is NULL"
+msgid "ExecAppend: subnode is NULL"
 msgstr ""
 
 #: ../executor/nodeHash.c:66
diff --git a/src/include/executor/nodeAppend.h b/src/include/executor/nodeAppend.h
index 740681b99170ed506c75b81db674b691e8811fe4..6819c809a2e3e5ab5696f4b775737d63e5ede599 100644
--- a/src/include/executor/nodeAppend.h
+++ b/src/include/executor/nodeAppend.h
@@ -7,7 +7,7 @@
  * Portions Copyright (c) 1996-2004, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
- * $PostgreSQL: pgsql/src/include/executor/nodeAppend.h,v 1.21 2004/08/29 04:13:06 momjian Exp $
+ * $PostgreSQL: pgsql/src/include/executor/nodeAppend.h,v 1.22 2004/09/24 01:36:37 neilc Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -18,7 +18,7 @@
 
 extern int	ExecCountSlotsAppend(Append *node);
 extern AppendState *ExecInitAppend(Append *node, EState *estate);
-extern TupleTableSlot *ExecProcAppend(AppendState *node);
+extern TupleTableSlot *ExecAppend(AppendState *node);
 extern void ExecEndAppend(AppendState *node);
 extern void ExecReScanAppend(AppendState *node, ExprContext *exprCtxt);
diff --git a/src/backend/executor/nodeAppend.c b/src/backend/executor/nodeAppend.c
index 431f4039fa1fc93617a7685f0efe4394173da705..f9e0463e969026aa6b6c61ef39a78579b7cdfc2d 100644
--- a/src/backend/executor/nodeAppend.c
+++ b/src/backend/executor/nodeAppend.c
@@ -8,13 +8,13 @@
  *
  *
  * IDENTIFICATION
- *	  $PostgreSQL: pgsql/src/backend/executor/nodeAppend.c,v 1.59 2004/08/29 04:12:31 momjian Exp $
+ *	  $PostgreSQL: pgsql/src/backend/executor/nodeAppend.c,v 1.60 2004/09/24 01:36:30 neilc Exp $
  *
  *-------------------------------------------------------------------------
  */
 /* INTERFACE ROUTINES
  *		ExecInitAppend	- initialize the append node
  *		ExecProcAppend	- retrieve the next tuple from the node
  *		ExecEndAppend	- shut down the append node
  *		ExecReScanAppend - rescan the append node
  *
@@ -90,7 +90,7 @@ exec_append_initialize_next(AppendState *appendstate)
 		/*
 		 * if scanning in reverse, we start at the last scan in the list
 		 * and then proceed back to the first.. in any case we inform
 		 * ExecProcAppend that we are at the end of the line by returning
 		 * FALSE
 		 */
 		appendstate->as_whichplan = appendstate->as_firstplan;
@@ -134,7 +134,7 @@ exec_append_initialize_next(AppendState *appendstate)
  *	   (This is potentially wasteful, since the entire result of the
  *		append node may not be scanned, but this way all of the
  *		structures get allocated in the executor's top level memory
  *		block instead of that of the call to ExecProcAppend.)
  *
  *		Special case: during an EvalPlanQual recheck query of an inherited
  *		target relation, we only want to initialize and scan the single
@@ -246,15 +246,13 @@ ExecCountSlotsAppend(Append *node)
 }
 
 /* ----------------------------------------------------------------
- *	   ExecProcAppend
+ *	   ExecAppend
  *
  *		Handles the iteration over the multiple scans.
- *
- *	   NOTE: Can't call this ExecAppend, that name is used in execMain.
  * ----------------------------------------------------------------
  */
 TupleTableSlot *
-ExecProcAppend(AppendState *node)
+ExecAppend(AppendState *node)
 {
 	EState	   *estate;
 	int			whichplan;
@@ -310,7 +308,7 @@ ExecProcAppend(AppendState *node)
 		if (exec_append_initialize_next(node))
 		{
 			ExecSetSlotDescriptorIsNew(result_slot, true);
-			return ExecProcAppend(node);
+			return ExecAppend(node);
 		}
 		else
 			return ExecClearTuple(result_slot);
@@ -8,13 +8,13 @@
 /* INTERFACE ROUTINES
  *		ExecInitAppend	- initialize the append node
- *		ExecProcAppend	- retrieve the next tuple from the node
+ *		ExecAppend		- retrieve the next tuple from the node
  *		ExecEndAppend	- shut down the append node
  *		ExecReScanAppend - rescan the append node
@@ -90,7 +90,7 @@ exec_append_initialize_next(AppendState *appendstate)
 		 * if scanning in reverse, we start at the last scan in the list
 		 * and then proceed back to the first.. in any case we inform
-		 * ExecProcAppend that we are at the end of the line by returning
+		 * ExecAppend that we are at the end of the line by returning
 		 * FALSE
 		 */
@@ -134,7 +134,7 @@ exec_append_initialize_next(AppendState *appendstate)
  *		append node may not be scanned, but this way all of the
  *		structures get allocated in the executor's top level memory
- *		block instead of that of the call to ExecProcAppend.)
+ *		block instead of that of the call to ExecAppend.)
  *
  *		Special case: during an EvalPlanQual recheck query of an inherited